"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const metadata_1 = require("@jfrog-pipelines/metadata");
const ApiStepDataAdapter_1 = require("./../ApiStepDataAdapter");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
describe('ApiStepDataAdapter', () => {
    describe('getBuildPlaneMessages', () => {
        it('should return an array of BuildPlaneMessageAttributes', async () => {
            const nodeId = 123;
            const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
            const expectedResponse = [
                {
                    id: 1,
                    nodeId: 123,
                    projectId: 1,
                    nodePoolId: 1,
                    statusCode: metadata_1.READY
                }
            ];
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getBuildPlaneMessages').mockResolvedValueOnce(expectedResponse);
            const queryString = `nodeIds=${nodeId}&statusCodes=${metadata_1.READY},${metadata_1.QUEUED}`;
            const messages = await adapter.getBuildPlaneMessages(queryString);
            expect(messages.length).toBeGreaterThan(0);
            expect(internal_clients_1.PipelinesClient.prototype.getBuildPlaneMessages).toHaveBeenCalledWith(queryString);
        });
    });
    describe('putBuildPlaneMessageById', () => {
        it('should return a BuildPlaneMessageAttributes', async () => {
            const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
            const nodeId = 123;
            const expectedResponse = {
                id: 1,
                projectId: 1,
                statusCode: metadata_1.READY
            };
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'putBuildPlaneMessageById').mockResolvedValueOnce(expectedResponse);
            await adapter.putBuildPlaneMessageById(nodeId, {
                resetBuildPlaneMessage: true,
                nodeId: nodeId
            });
            expect(internal_clients_1.PipelinesClient.prototype.putBuildPlaneMessageById).toHaveBeenCalledWith(nodeId, {
                resetBuildPlaneMessage: true,
                nodeId: nodeId
            });
        });
    });
});
//# sourceMappingURL=ApiStepDataAdapter.test.js.map