"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utility_1 = require("@jfrog-pipelines/utility");
const microservice_1 = require("@jfrog-pipelines/microservice");
const CommandFactory_1 = require("../CommandFactory");
const NodeStatsCleanupHandler_1 = require("../nodeStats/NodeStatsCleanupHandler");
const NodeStatsCleanupCommand_1 = require("../nodeStats/NodeStatsCleanupCommand");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { allowDynamicNodes: true, allowCustomNodes: true } }
    };
});
const store = microservice_1.applicationContext;
store.set(microservice_1.SYSTEM_SERVICE_INSTANCE_INITIALIZER, { systemServiceInstancesId: 1 });
describe('Command Factory Test', () => {
    it('should return command of type NodeStatCommand', () => {
        const payload = {
            command: {
                actor: utility_1.Actor.nodeStats,
                operation: utility_1.Operation.delete
            }
        };
        const command = CommandFactory_1.CommandFactory.getCommand(payload);
        expect(command).toBeInstanceOf(NodeStatsCleanupCommand_1.NodeStatsCleanupCommand);
    });
    it('should get a handler of nodestats with valid payload', () => {
        const nodeStatsCleanupCommand = new NodeStatsCleanupCommand_1.NodeStatsCleanupCommand(utility_1.Operation.delete);
        const handler = CommandFactory_1.CommandFactory.getHandler(nodeStatsCleanupCommand);
        expect(handler).toBeInstanceOf(NodeStatsCleanupHandler_1.NodeStatsCleanupHandler);
    });
    it('should throw error as command is not valid', () => {
        const payload = {
            command: {
                actor: utility_1.Actor.nodeStats,
                operation: utility_1.Operation.delete
            }
        };
        expect(() => CommandFactory_1.CommandFactory.getHandler(payload)).toThrow('Invalid command');
    });
});
//# sourceMappingURL=CommandFactory.test.js.map