"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const BuildPlaneDao_1 = require("../BuildPlaneDao");
const BuildPlaneService_1 = require("../BuildPlaneService");
describe('Test BuildPlaneService #getMessageCount', () => {
    it('returns 0 if pool id not found', async () => {
        const service = new BuildPlaneService_1.BuildPlaneService();
        const dao = new BuildPlaneDao_1.BuildPlaneDao();
        const poolID = 1;
        const spyGetMessageCount = jest.spyOn(BuildPlaneDao_1.BuildPlaneDao.prototype, 'count').mockResolvedValueOnce(0);
        const count = await service.getReadyMessageCount(poolID);
        expect(dao.count).toHaveBeenCalledTimes(1);
        expect(count).toBe(0);
        spyGetMessageCount.mockClear();
    });
    it('returns count if pool id  found', async () => {
        const service = new BuildPlaneService_1.BuildPlaneService();
        const dao = new BuildPlaneDao_1.BuildPlaneDao();
        const poolID = 5;
        const spyGetMessageCount = jest.spyOn(BuildPlaneDao_1.BuildPlaneDao.prototype, 'count').mockResolvedValueOnce(1);
        const count = await service.getReadyMessageCount(poolID);
        expect(dao.count).toHaveBeenCalledTimes(1);
        expect(count).toBe(1);
        spyGetMessageCount.mockClear();
    });
});
describe('Test BuildPlaneService #getReadyMessages', () => {
    it('returns buildPlaneMessages when they exist', async () => {
        const service = new BuildPlaneService_1.BuildPlaneService();
        const dao = new BuildPlaneDao_1.BuildPlaneDao();
        const expectedResponse = [
            {
                projectId: 1,
                pipelineId: 1,
                runId: 1,
                nodePoolId: 1,
                statusCode: 4015,
                priority: 1000,
                payload: {},
                triggeredAt: new Date()
            }
        ];
        const spyGetMessageCount = jest.spyOn(BuildPlaneDao_1.BuildPlaneDao.prototype, 'findAll').mockResolvedValueOnce(expectedResponse);
        const messages = await service.getReadyMessages(1);
        expect(spyGetMessageCount).toHaveBeenCalledTimes(1);
        expect(dao.findAll).toHaveBeenCalledTimes(1);
        expect(messages).toBe(expectedResponse);
    });
    it('returns empty array when no buildPlaneMessages exist', async () => {
        const service = new BuildPlaneService_1.BuildPlaneService();
        const dao = new BuildPlaneDao_1.BuildPlaneDao();
        const expectedResponse = [];
        const spyGetMessageCount = jest.spyOn(BuildPlaneDao_1.BuildPlaneDao.prototype, 'findAll').mockResolvedValueOnce(expectedResponse);
        const messages = await service.getReadyMessages(1);
        expect(spyGetMessageCount).toHaveBeenCalledTimes(1);
        expect(dao.findAll).toHaveBeenCalledTimes(1);
        expect(messages).toBe(expectedResponse);
    });
});
//# sourceMappingURL=BuildPlaneService.test.js.map